import { registerBlockType } from '@wordpress/blocks';
import { useBlockProps, InnerBlocks } from '@wordpress/block-editor';

registerBlockType('custom/meet-the-team', {
  title: 'Meet The Team Section',
  icon: 'groups',
  category: 'widgets',
  edit() {
    const blockProps = useBlockProps({ className: 'meet-the-team-section bg-white py-16 px-6 md:px-12' });

    return (
      <section {...blockProps}>
        <div className="max-w-screen-xl mx-auto flex flex-col lg:flex-row gap-10 relative">
          <div className="w-full lg:w-1/3 space-y-6 lg:sticky lg:top-16 self-start" data-aos="fade-up" data-aos-duration="1000" data-rellax-speed="-2">
            <h2 className="text-4xl font-semibold leading-tight">Meet The Team</h2>
            <p className="text-base text-gray-700">
              We're an award-winning multidisciplinary team based in Philadelphia with a passion for creating innovative architecture.
            </p>
            <p className="text-base text-gray-700">
              Associate Kara Cohen, Office Manager Justin Klein, Designer Andy Morris
            </p>
            <blockquote className="border-l-4 pl-4 italic text-gray-600 mt-8">
              "Alex was there every step of the way and brought my vision further than I could have imagined!"
              <div className="flex items-center gap-4 mt-4">
                <div className="w-12 h-12 bg-cover bg-center rounded-full" style={{ backgroundImage: "url('https://adhsite.space/uitest/wp-content/uploads/2021/11/linkedin-sales-solutions-pAtA8xe_iVM-unsplash.jpg')" }}></div>
                <div>
                  <div className="font-semibold">Josh Margolis</div>
                  <div className="text-sm text-gray-500">Founder of DAF</div>
                </div>
              </div>
            </blockquote>
          </div>

          {/* Team Members Section Editable */}
          <div className="w-full lg:w-2/3 flex flex-col gap-10">
            <InnerBlocks
              allowedBlocks={['core/group', 'core/image', 'core/heading', 'core/paragraph']}
              templateLock={false}
            />
          </div>
        </div>
      </section>
    );
  },
  save() {
    const blockProps = useBlockProps.save({ className: 'meet-the-team-section bg-white py-16 px-6 md:px-12' });
    return (
      <section {...blockProps}>
        <div className="max-w-screen-xl mx-auto flex flex-col lg:flex-row gap-10 relative">
          <div className="w-full lg:w-1/3 space-y-6 lg:sticky lg:top-16 self-start">
            <h2 className="text-4xl font-semibold leading-tight">Meet The Team</h2>
            <p className="text-base text-gray-700">
              We're an award-winning multidisciplinary team based in Philadelphia with a passion for creating innovative architecture.
            </p>
            <p className="text-base text-gray-700">
              Associate Kara Cohen, Office Manager Justin Klein, Designer Andy Morris
            </p>
            <blockquote className="border-l-4 pl-4 italic text-gray-600 mt-8">
              "Alex was there every step of the way and brought my vision further than I could have imagined!"
              <div className="flex items-center gap-4 mt-4">
                <div className="w-12 h-12 bg-cover bg-center rounded-full" style={{ backgroundImage: "url('https://adhsite.space/uitest/wp-content/uploads/2021/11/linkedin-sales-solutions-pAtA8xe_iVM-unsplash.jpg')" }}></div>
                <div>
                  <div className="font-semibold">Josh Margolis</div>
                  <div className="text-sm text-gray-500">Founder of DAF</div>
                </div>
              </div>
            </blockquote>
          </div>
          <div className="w-full lg:w-2/3 flex flex-col gap-10">
            <InnerBlocks.Content />
          </div>
        </div>
      </section>
    );
  }
});
